@@ -14,10 +14,9 @@ pub fn proper_noun(
         .as_str()
         .ok_or_else(|| RenderError::new("not string"))?;
     let str = str
-        .split_ascii_whitespace()
+        .split_inclusive(&['-', ' ', '/'][..])
         .map(|x| format!("{}{}", x[0..1].to_uppercase(), &x[1..]))
-        .collect::<Vec<String>>()
-        .join(" ");
+        .collect::<String>();
     out.write(&str)?;
     Ok(())
 }
