@@ -7,12 +7,15 @@ impl From<In> for Out {
             name,
             flavour_text,
             features,
+            caster_type
         } = val;
         let features = features.into_iter().map(|x| x.into()).collect();
+        let caster_type = caster_type.into();
         Out {
             name,
             features,
             flavour_text,
+            caster_type
         }
     }
 }
